@@ -12,6 +12,7 @@
 #
 
 from django.utils.translation import gettext as _
+from django.conf import settings
 from inspect import stack
 from datetime import datetime
 from datetime import timedelta
@@ -417,4 +418,49 @@ def ceil_strdate(str_date, start):
             int(str_date[8:10]), 0, 0, 0, 0)
     else:
         return datetime(int(str_date[0:4]), int(str_date[5:7]),
-            int(str_date[8:10]), 23, 59, 59, 999999)
\ No newline at end of file
+            int(str_date[8:10]), 23, 59, 59, 999999)
+
+
+def get_pagination_vars(request, col_field_list, default_sort_field):
+    """Return data for django pagination with sort order"""
+    # Define no of records per page
+    PAGE_SIZE = settings.PAGE_SIZE
+    try:
+        PAGE_NUMBER = int(request.GET['page'])
+    except:
+        PAGE_NUMBER = 1
+
+    # page index
+    if PAGE_NUMBER > 1:
+        start_page = (PAGE_NUMBER - 1) * int(PAGE_SIZE)
+        end_page = start_page + int(PAGE_SIZE)
+    else:
+        start_page = int(0)
+        end_page = int(PAGE_SIZE)
+
+    # default column order
+    col_name_with_order = {}
+    for field_name in col_field_list:
+        col_name_with_order[field_name] = '-' + field_name
+
+    sort_field = variable_value(request, 'sort_by')
+    if not sort_field:
+        sort_field = default_sort_field  # default sort field
+        sort_order = '-' + sort_field  # desc
+    else:
+        if "-" in sort_field:
+            sort_order = sort_field
+            col_name_with_order[sort_field[1:]] = sort_field[1:]
+        else:
+            sort_order = sort_field
+            col_name_with_order[sort_field] = '-' + sort_field
+
+    data = {
+        'PAGE_SIZE': PAGE_SIZE,
+        'PAGE_NUMBER': PAGE_NUMBER,
+        'start_page': start_page,
+        'end_page': end_page,
+        'col_name_with_order': col_name_with_order,
+        'sort_order': sort_order,
+    }
+    return data
\ No newline at end of file
